@@ -5,16 +5,16 @@ from pydantic import BaseModel
 
 
 class DeleteSweepConfig(BaseModel):
-    sweep_id: str
+    name: str
 
 
 class DeleteSweepCommand(ClientCommand):
 
-    DESCRIPTION = "Command to delete a Sweep"
+    description = "Delete a Sweep."
 
     def run(self) -> None:
         parser = ArgumentParser()
-        parser.add_argument("sweep_id", type=str, help="The associated `sweep_id` to delete.")
+        parser.add_argument("--name", type=str, required=True, help="The associated `sweep_id` to delete.")
         hparams = parser.parse_args()
-        response = self.invoke_handler(config=DeleteSweepConfig(sweep_id=hparams.sweep_id))
+        response = self.invoke_handler(config=DeleteSweepConfig(name=hparams.name))
         print(response)
