@@ -1,8 +1,7 @@
 import time
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, Optional
 
 from lightning.app.components.training import LightningTrainingComponent, PyTorchLightningScriptRunner
-from lightning.app.storage.drive import Drive
 
 from lightning_hpo.framework.agnostic import Objective
 
@@ -20,7 +19,6 @@ class PyTorchLightningObjective(Objective, PyTorchLightningScriptRunner):
         experiment_id: int,
         experiment_name: str,
         num_nodes: int,
-        drives: List[Drive],
         **kwargs,
     ):
         Objective.__init__(
@@ -29,7 +27,6 @@ class PyTorchLightningObjective(Objective, PyTorchLightningScriptRunner):
             sweep_id=sweep_id,
             experiment_id=experiment_id,
             experiment_name=experiment_name,
-            drives=drives,
             **kwargs,
         )
         PyTorchLightningScriptRunner.__init__(self, *args, num_nodes=num_nodes, **kwargs)
@@ -37,8 +34,6 @@ class PyTorchLightningObjective(Objective, PyTorchLightningScriptRunner):
         self.total_parameters = None
         self.start_time = None
         self.end_time = None
-        for drive_idx, drive in enumerate(drives):
-            setattr(self, f"drive__{drive_idx}", drive)
 
     def configure_tracer(self):
         tracer = Objective.configure_tracer(self)
@@ -129,7 +124,6 @@ class ObjectiveLightningTrainingComponent(LightningTrainingComponent):
         logger: str,
         sweep_id: str,
         num_nodes: int = 1,
-        drives: List[Drive],
         **kwargs,
     ):
         super().__init__(
@@ -140,7 +134,6 @@ class ObjectiveLightningTrainingComponent(LightningTrainingComponent):
             experiment_id=experiment_id,
             experiment_name=experiment_name,
             num_nodes=num_nodes,
-            drives=drives,
             **kwargs,
         )
         self.experiment_id = experiment_id
